VVideoCompressionConfig class

Configuration for video compression operations

Constructors

VVideoCompressionConfig({required VVideoCompressQuality quality, String? outputPath, bool deleteOriginal = false, bool fallbackToOriginalIfNotSmaller = true, bool saveToGallery = false, bool includeAudio = true, bool includeMetadata = true, bool optimizeForStreaming = true, bool copyMetadata = true, bool useHardwareAcceleration = true, bool useFastStart = true, bool useTwoPassEncoding = false, bool useVariableBitrate = true, VVideoAdvancedConfig? advanced})
const
VVideoCompressionConfig.fromMap(Map<String, dynamic> map)
factory
VVideoCompressionConfig.high({String? outputPath, bool deleteOriginal = false, bool fallbackToOriginalIfNotSmaller = true, bool saveToGallery = false, bool includeAudio = true, bool includeMetadata = true, bool optimizeForStreaming = true, bool copyMetadata = true, bool useHardwareAcceleration = true, bool useFastStart = true, bool useTwoPassEncoding = false, bool useVariableBitrate = true, VVideoAdvancedConfig? advanced})
const
VVideoCompressionConfig.low({String? outputPath, bool deleteOriginal = false, bool fallbackToOriginalIfNotSmaller = true, bool saveToGallery = false, bool includeAudio = true, bool includeMetadata = true, bool optimizeForStreaming = true, bool copyMetadata = true, bool useHardwareAcceleration = true, bool useFastStart = true, bool useTwoPassEncoding = false, bool useVariableBitrate = true, VVideoAdvancedConfig? advanced})
const
VVideoCompressionConfig.medium({String? outputPath, bool deleteOriginal = false, bool fallbackToOriginalIfNotSmaller = true, bool saveToGallery = false, bool includeAudio = true, bool includeMetadata = true, bool optimizeForStreaming = true, bool copyMetadata = true, bool useHardwareAcceleration = true, bool useFastStart = true, bool useTwoPassEncoding = false, bool useVariableBitrate = true, VVideoAdvancedConfig? advanced})
const

Properties

advanced VVideoAdvancedConfig?
Advanced compression settings (optional)
final
copyMetadata bool
Whether to copy metadata from original video
final
deleteOriginal bool
Whether to delete the original video file after compression
final
fallbackToOriginalIfNotSmaller bool
Whether to return the original file when compression saves less than 5%.
final
hashCode int
The hash code for this object.
no setterinherited
includeAudio bool
Whether to include audio in the compressed video
final
includeMetadata bool
Whether to include metadata in the compressed video
final
optimizeForStreaming bool
Whether to optimize for streaming
final
outputPath String?
Custom output path for the compressed video (optional)
final
quality VVideoCompressQuality
Quality level for the compressed video
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveToGallery bool
Whether to save the compressed video to gallery
final
useFastStart bool
Whether to use fast start
final
useHardwareAcceleration bool
Whether to use hardware acceleration
final
useTwoPassEncoding bool
Whether to use two pass encoding
final
useVariableBitrate bool
Whether to use variable bitrate
final

Methods

isValid() bool
Validates the configuration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited