VVideoStreamManager class

Global stream manager for video compression progress events

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

hasListeners → bool
Check if someone is listening to the stream
no setter
instance → VVideoStreamManager
no setter
isActive → bool
Check if the global stream is active
no setter
lastProgressEvent → VVideoProgressEvent?
Get the latest progress event (if any)
no setter
listenerCount → int
Get the current number of listeners
no setter
progressStream → Stream<VVideoProgressEvent>
Global progress stream - accessible from anywhere
no setter

Static Methods

dispose() → void
Manually dispose the global stream (usually not needed)
listen(void onProgress(VVideoProgressEvent event), {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription<VVideoProgressEvent>
Convenience method to listen to progress with typed callback
listenToBatchProgress(void onProgress(double progress, int currentIndex, int total), {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription<VVideoProgressEvent>
Convenience method to listen to batch progress
listenToProgress(void onProgress(double progress), {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription<VVideoProgressEvent>
Convenience method to listen to progress with simple callback