VVideoThumbnailResult class

Video thumbnail result

Constructors

VVideoThumbnailResult({required String thumbnailPath, required int width, required int height, required int fileSizeBytes, required VThumbnailFormat format, required int timeMs})
const
VVideoThumbnailResult.fromMap(Map<String, dynamic> map)
factory

Properties

fileSizeBytes int
The file size of the thumbnail in bytes
final
fileSizeFormatted String
no setter
format VThumbnailFormat
The format of the generated thumbnail
final
hashCode int
The hash code for this object.
no setterinherited
height int
The height of the generated thumbnail
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailPath String
The path to the generated thumbnail file
final
timeMs int
The timestamp in milliseconds where the thumbnail was extracted from
final
width int
The width of the generated thumbnail
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited