MethodChannelVVideoCompressor class

An implementation of VVideoCompressorPlatform that uses method channels.

Inheritance

Properties

eventChannel → EventChannel
The event channel for progress updates
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelCompression() → Future<void>
override
cleanup() → Future<void>
override
cleanupFiles({bool deleteThumbnails = true, bool deleteCompressedVideos = false, bool clearCache = true}) → Future<void>
override
compressVideo(String videoPath, VVideoCompressionConfig config, {void onProgress(double progress)?}) → Future<VVideoCompressionResult?>
override
compressVideos(List<String> videoPaths, VVideoCompressionConfig config, {void onProgress(double progress, int currentIndex, int total)?}) → Future<List<VVideoCompressionResult>>
override
getCompressionEstimate(String videoPath, VVideoCompressQuality quality, {VVideoAdvancedConfig? advanced}) → Future<VVideoCompressionEstimate?>
override
getPlatformVersion() → Future<String?>
override
getVideoInfo(String videoPath) → Future<VVideoInfo?>
override
getVideoThumbnail(String videoPath, VVideoThumbnailConfig config) → Future<VVideoThumbnailResult?>
override
getVideoThumbnails(String videoPath, List<VVideoThumbnailConfig> configs) → Future<List<VVideoThumbnailResult>>
override
isCompressing() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited