VDimensionHandling enum
Dimension alignment handling behavior
Values
- autoAlign → const VDimensionHandling
-
const VDimensionHandling('AUTO_ALIGN', 'Auto align dimensions to 16-pixel boundaries when needed') - letterbox → const VDimensionHandling
-
const VDimensionHandling('LETTERBOX', 'Add black bars to maintain aspect ratio during alignment') - exact → const VDimensionHandling
-
const VDimensionHandling('EXACT', 'Keep exact dimensions without alignment (may cause artifacts)')
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VDimensionHandling> - A constant List of the values in this enum, in order of their declaration.